==> zk-3.6.0.jar: web/js/zk/html/lang/mesg_sv.org.js <==
/* mesg.js "charset=utf-8"

{{IS_NOTE
	Purpose:
		Locale dependent message
	Description:
		
	History:
		Created by Easit AB (http://www.easit.com) April 2007
}}IS_NOTE

Copyright (C) 2005-2007 Potix Corporation. All Rights Reserved.

{{IS_RIGHT
	This program is distributed under GPL Version 3.0 in the hope that
	it will be useful, but WITHOUT ANY WARRANTY.
}}IS_RIGHT
*/
mesg = {};
mesg.NOT_FOUND = "Ej hittat: ";
mesg.UNSUPPORTED = "Stödjes inte än: ";
mesg.FAILED_TO_SEND = "Kunde inte sända begäran till servern.";
mesg.FAILED_TO_RESPONSE = "Servern kunde inte hantera din begäran.";
mesg.TRY_AGAIN = "Try again?";
mesg.UNSUPPORTED_BROWSER = "Icke-supportad webbläsare: ";
mesg.ILLEGAL_RESPONSE = "Okänt svar från server. Var god uppdatera sidan och försök igen..\n";
mesg.FAILED_TO_PROCESS = "Kunde inte hantera ";
mesg.UUID_REQUIRED = "UUID krävs";
mesg.INVALID_STRUCTURE = "Ogiltig struktur: ";
mesg.COMP_OR_UUID_REQUIRED = "Komponent eller dess UUID krävs";
mesg.NUMBER_REQUIRED = "Du måste ange en siffra, istället för ";
mesg.INTEGER_REQUIRED = "Du måste ange ett heltal, istället för ";
mesg.EMPTY_NOT_ALLOWED = "Blank inte tillåtet.\nDu kan inte ange annat än blanksteg";
mesg.GOTO_ERROR_FIELD = "Gå till felaktigt fält";
mesg.PLEASE_WAIT = "Arbetar...";
mesg.VALUE_NOT_MATCHED = "You must specify one of values in the drop-down list.";

mesg.FILE_SIZE = "Filstorlek: ";
mesg.KBYTES = "KB";

mesg.CANCEL="Avbryt";

mesg.FAILED_TO_LOAD = "Uppladdning misslyckades ";
mesg.FAILED_TO_LOAD_DETAIL = "Kan ha orsakats av trafikstörning. Ladda om denna sida och försök igen.";
mesg.CAUSE = "Orsak: ";

mesg.LOADING = "Arbetar...";

==> zk-3.6.4.jar: web/js/zk/html/lang/mesg_sv.org.js <==
/* mesg.js "charset=utf-8"

{{IS_NOTE
	Purpose:
		Locale dependent message
	Description:
		
	History:
		Created by Easit AB (http://www.easit.com) April 2007
}}IS_NOTE

Copyright (C) 2005-2007 Potix Corporation. All Rights Reserved.

{{IS_RIGHT
	This program is distributed under GPL Version 3.0 in the hope that
	it will be useful, but WITHOUT ANY WARRANTY.
}}IS_RIGHT
*/
mesg = {};
mesg.NOT_FOUND = "Ej hittat: ";
mesg.UNSUPPORTED = "Stödjes inte än: ";
mesg.FAILED_TO_SEND = "Kunde inte sända begäran till servern.";
mesg.FAILED_TO_RESPONSE = "Servern kunde inte hantera din begäran.";
mesg.TRY_AGAIN = "Försök igen?";
mesg.UNSUPPORTED_BROWSER = "Icke-supportad webbläsare: ";
mesg.ILLEGAL_RESPONSE = "Okänt svar från server. Var god uppdatera sidan och försök igen..\n";
mesg.FAILED_TO_PROCESS = "Kunde inte hantera ";
mesg.UUID_REQUIRED = "UUID krävs";
mesg.INVALID_STRUCTURE = "Ogiltig struktur: ";
mesg.COMP_OR_UUID_REQUIRED = "Komponent eller dess UUID krävs";
mesg.NUMBER_REQUIRED = "Du måste ange en siffra, istället för ";
mesg.INTEGER_REQUIRED = "Du måste ange ett heltal, istället för ";
mesg.EMPTY_NOT_ALLOWED = "Blank inte tillåtet.";
mesg.GOTO_ERROR_FIELD = "Gå till felaktigt fält";
mesg.PLEASE_WAIT = "Arbetar...";
mesg.VALUE_NOT_MATCHED = "Du måste välja ett av värdena i rull-listan.";

mesg.FILE_SIZE = "Filstorlek: ";
mesg.KBYTES = "KB";

mesg.CANCEL="Avbryt";

mesg.FAILED_TO_LOAD = "Uppladdning misslyckades ";
mesg.FAILED_TO_LOAD_DETAIL = "Kan ha orsakats av trafikstörning. Ladda om denna sida och försök igen.";
mesg.CAUSE = "Orsak: ";

mesg.LOADING = "Arbetar...";
